@@ -11,7 +11,7 @@ known_conditions = ["temperature"]
 def ingest_table(material_run, table):
     """Ingest a material run into an existing table."""
     for _, row in table.iterrows():
-        exp = MeasurementRun()
+        exp = MeasurementRun("Material Run")
         for prop_name in known_properties:
             if prop_name in row:
                 exp.properties.append(Property(name=prop_name,
